@@ -87,7 +87,7 @@ def test_warns_when_scope_argument_is_present(pytester: Pytester):
             """
         )
     )
-    result = pytester.runpytest_subprocess("--asyncio-mode=strict")
+    result = pytester.runpytest("--asyncio-mode=strict", "--assert=plain")
     result.assert_outcomes(passed=1, warnings=1)
     result.stdout.fnmatch_lines("*DeprecationWarning*")
 
@@ -157,7 +157,7 @@ def test_asyncio_mark_respects_parametrized_loop_policies(
             """
         )
     )
-    result = pytester.runpytest_subprocess("--asyncio-mode=strict")
+    result = pytester.runpytest("--asyncio-mode=strict")
     result.assert_outcomes(passed=2)
 
 
@@ -188,7 +188,7 @@ def test_asyncio_mark_provides_function_scoped_loop_to_fixtures(
             """
         )
     )
-    result = pytester.runpytest_subprocess("--asyncio-mode=strict")
+    result = pytester.runpytest("--asyncio-mode=strict")
     result.assert_outcomes(passed=1)
 
 
@@ -242,7 +242,7 @@ def test_standalone_test_does_not_trigger_warning_about_no_current_event_loop_be
             """
         )
     )
-    result = pytester.runpytest_subprocess("--asyncio-mode=strict")
+    result = pytester.runpytest("--asyncio-mode=strict", "--assert=plain")
     result.assert_outcomes(warnings=0, passed=1)
 
 
@@ -274,5 +274,5 @@ def test_asyncio_mark_does_not_duplicate_other_marks_in_auto_mode(
             """
         )
     )
-    result = pytester.runpytest_subprocess("--asyncio-mode=auto")
+    result = pytester.runpytest("--asyncio-mode=auto", "--assert=plain")
     result.assert_outcomes(warnings=0, passed=1)
